@@ -4,21 +4,22 @@
 # fieldformat.py, provides non-GUI base classes for field formating
 #
 # TreeLine, an information storage program
-# Copyright (C) 2005, Douglas W. Bell
+# Copyright (C) 2006, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
-# terms of the GNU General Public License, Version 2.  This program is
-# distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
+# terms of the GNU General Public License, either Version 2 or any later
+# version.  This program is distributed in the hope that it will be useful,
+# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
 #****************************************************************************
 
+import re
+from xml.sax.saxutils import escape, unescape
 from gennumber import GenNumber, GenNumberError
 from gendate import GenDate, GenDateError
 from gentime import GenTime, GenTimeError
 from genboolean import GenBoolean, GenBooleanError
 import treedoc
 import globalref
-from xml.sax.saxutils import escape, unescape
-import re
 
 _errorStr = '#####'
 
@@ -41,7 +42,7 @@ def xslEscape(text):
     return nonTagRe.sub(esc, text)
 
 
-class TextFormat:
+class TextFormat(object):
     """Holds format info for a normal text field"""
     typeName = 'Text'
     sortSequence = 20
@@ -67,9 +68,11 @@ class TextFormat:
         self.html = attrs.get(u'html', '').startswith('y') and True or False
         self.isRequired = attrs.get(u'required', '').startswith('y') and \
                           True or False
-        self.hidden = attrs.get(u'hidden', '').startswith('y') and True or False
+        self.hidden = attrs.get(u'hidden', '').startswith('y') and \
+                      True or False
         try:
-            self.numLines = int(attrs.get(u'lines', repr(self.defaultNumLines)))
+            self.numLines = int(attrs.get(u'lines',
+                                          repr(self.defaultNumLines)))
         except ValueError:
             self.numLines = 1
         self.initDefault = attrs.get(u'init', '')
@@ -80,7 +83,7 @@ class TextFormat:
         self.initFormat()
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         pass
 
     def duplicateSettings(self, otherField):
@@ -145,7 +148,7 @@ class TextFormat:
         if self.initDefault:
             text += u' init="%s"' % escape(self.initDefault, treedoc.escDict)
         if self.linkAltField:
-            text += u' linkalt="%s"' % escape(self.linkAltField, \
+            text += u' linkalt="%s"' % escape(self.linkAltField,
                                               treedoc.escDict)
         return text
 
@@ -168,7 +171,6 @@ class TextFormat:
         prefix = self.prefix
         suffix = self.suffix
         if titleMode:
-            storedText = storedText.split('\n', 1)[0]    # truncate to 1st line
             if self.html:
                 storedText = self.removeMarkup(storedText)
             if globalref.docRef.formHtml:
@@ -229,7 +231,7 @@ class TextFormat:
 
     def xslText(self):
         """Return what we need to write into an  XSL file for this type"""
-        return u'<xsl:if test="normalize-space(./%s)">%s' \
+        return u'<xsl:if test="normalize-space(./%s)">%s'\
                 '<xsl:value-of select="./%s"/>%s</xsl:if>' % \
                 (self.name, xslEscape(self.prefix), self.name,
                  xslEscape(self.suffix))
@@ -254,24 +256,24 @@ class NumberFormat(TextFormat):
     typeName = 'Number'
     sortSequence = 10
     #field format edit options:
-    defaultFormat = '#.##'
-    formatMenuList = [(u'%s\t%s' % (_('Optional Digit'), '#'), '#'), \
-                      (u'%s\t%s' % (_('Required Digit'), '0'), '0'), \
-                      (u'%s\t%s' % (_('Digit or Space (external)'), \
-                                    _('<space>')), ' '), \
-                      None, \
-                      (u'%s\t%s' % (_('Decimal Point'), '.'), '.'), \
-                      (u'%s\t%s' % (_('Decimal Comma'), ','), ','), \
-                      None, \
-                      (u'%s\t%s' % (_('Comma Separator'), '\,'), '\,'), \
-                      (u'%s\t%s' % (_('Dot Separator'), '\.'), '\.'), \
-                      (u'%s\t%s' % (_('Space Separator (internal)'), \
-                                    _('<space>')), ' '), \
-                      None, \
-                      (u'%s\t%s' % (_('Optional Sign'), '-'), '-'), \
-                      (u'%s\t%s' % (_('Required Sign'), '+'), '+'), \
-                      None, \
-                      (u'%s\t%s' % (_('Exponent (capital)'), 'E'), 'E'), \
+    defaultFormat = u'#.##'
+    formatMenuList = [(u'%s\t%s' % (_('Optional Digit'), '#'), '#'),
+                      (u'%s\t%s' % (_('Required Digit'), '0'), '0'),
+                      (u'%s\t%s' % (_('Digit or Space (external)'),
+                                    _('<space>')), ' '),
+                      None,
+                      (u'%s\t%s' % (_('Decimal Point'), '.'), '.'),
+                      (u'%s\t%s' % (_('Decimal Comma'), ','), ','),
+                      None,
+                      (u'%s\t%s' % (_('Comma Separator'), '\,'), '\,'),
+                      (u'%s\t%s' % (_('Dot Separator'), '\.'), '\.'),
+                      (u'%s\t%s' % (_('Space Separator (internal)'),
+                                    _('<space>')), ' '),
+                      None,
+                      (u'%s\t%s' % (_('Optional Sign'), '-'), '-'),
+                      (u'%s\t%s' % (_('Required Sign'), '+'), '+'),
+                      None,
+                      (u'%s\t%s' % (_('Exponent (capital)'), 'E'), 'E'),
                       (u'%s\t%s' % (_('Exponent (small)'), 'e'), 'e')]
 
     def __init__(self, name, attrs={}):
@@ -318,8 +320,8 @@ class ChoiceFormat(TextFormat):
     editSep = '/'
     #field format edit options:
     defaultFormat = '1/2/3/4'
-    formatMenuList = [(u'%s\t%s' % (_('Separator'), '/'), '/'), None, \
-                      (u'%s\t%s' % (_('"/" Character'), '//'), '//'), None, \
+    formatMenuList = [(u'%s\t%s' % (_('Separator'), '/'), '/'), None,
+                      (u'%s\t%s' % (_('"/" Character'), '//'), '//'), None,
                       (u'%s\t%s' % (_('Example'), '1/2/3/4'), '1/2/3/4')]
     hasEditChoices = True
 
@@ -328,7 +330,7 @@ class ChoiceFormat(TextFormat):
         TextFormat.__init__(self, name, attrs)
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         self.formatList = self.splitText(self.format)
 
     def formatOutput(self, storedText, titleMode, internal=False):
@@ -353,8 +355,8 @@ class ChoiceFormat(TextFormat):
 
     def getEditChoices(self, currentText=''):
         """Return list of choices for combo box, 
-           each a tuple of edit text and annotated text"""
-        return [(text, text) for text in self.formatList]
+           each a tuple of edit text and any annotation text"""
+        return [(text, '') for text in self.formatList]
 
     def initDefaultChoices(self):
         """Return a list of choices for setting the init default"""
@@ -362,8 +364,8 @@ class ChoiceFormat(TextFormat):
 
     def splitText(self, textStr):
         """Split textStr using editSep, double sep's become char"""
-        return [text.strip().replace('\0', self.editSep) for text in \
-                textStr.replace(self.editSep * 2, '\0').\
+        return [text.strip().replace('\0', self.editSep) for text in
+                textStr.replace(self.editSep * 2, '\0').
                 split(self.editSep)]
 
 
@@ -377,11 +379,11 @@ class CombinationFormat(ChoiceFormat):
         ChoiceFormat.__init__(self, name, attrs)
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         ChoiceFormat.initFormat(self)
         fullFormat = ''.join(self.formatList)
         try:
-            self.sep = [sep for sep in CombinationFormat.outputSepList \
+            self.sep = [sep for sep in CombinationFormat.outputSepList
                         if sep not in fullFormat][0] + ' '
         except IndexError:
             self.sep = CombinationFormat.outputSepList[0] + ' '
@@ -424,25 +426,26 @@ class CombinationFormat(ChoiceFormat):
 
     def getEditChoices(self, currentText=''):
         """Return list of choices for combo box,
-           each a tuple of edit text and annotated text"""
+           each a tuple of edit text and any annotation text"""
         currentChoices, valid = self.sortedChoices(currentText)
-        nonChoices = [text for text in self.formatList \
+        nonChoices = [text for text in self.formatList
                       if text not in currentChoices]
         results = []
         for choice in nonChoices:      # menu entries to add a choice
             allChoices = currentChoices + [choice]
-            allChoices = [text for text in self.formatList \
+            allChoices = [text for text in self.formatList
                           if text in allChoices]
-            results.append((self.editSep.join(allChoices), \
-                            choice + _('  (add)')))
-        results.append((None, None))   # separator
+            results.append((self.editSep.join(allChoices),
+                            '(%s %s)' % (_('add'), choice)))
+        if currentChoices:
+            results.append((None, None))   # separator
         for choice in currentChoices:   # menu entries to remove a choice
             allChoices = currentChoices[:]
             allChoices.remove(choice)
-            allChoices = [text for text in self.formatList \
+            allChoices = [text for text in self.formatList
                           if text in allChoices]
-            results.append((self.editSep.join(allChoices), \
-                            choice + _('  (remove)')))
+            results.append((self.editSep.join(allChoices),
+                            '(%s %s)' % (_('remove'), choice)))
         return results
 
     def initDefaultChoices(self):
@@ -464,7 +467,7 @@ class AutoChoiceFormat(ChoiceFormat):
         TextFormat.__init__(self, name, attrs)
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         self.formatList = []
 
     def addChoice(self, choice, sort=False):
@@ -500,21 +503,21 @@ class DateFormat(TextFormat):
     typeName = 'Date'
     sortSequence = 5
     #field format edit options:
-    defaultFormat = 'mmmm d, yyyy'
+    defaultFormat = u'mmmm d, yyyy'
     dateStampStrings = ('Now', _('Now', 'date stamp setting'))
-    formatMenuList = [(u'%s\t%s' % (_('Day (1 or 2 digits)'), 'd'), 'd'), \
-                      (u'%s\t%s' % (_('Day (2 digits)'), 'dd'), 'dd'), \
-                      None, \
-                      (u'%s\t%s' % (_('Month (1 or 2 digits)'), 'm'), 'm'), \
-                      (u'%s\t%s' % (_('Month (2 digits)'), 'mm'), 'mm'), \
-                      (u'%s\t%s' % (_('Month Abbreviation'), 'mmm'), 'mmm'), \
-                      (u'%s\t%s' % (_('Month Name'), 'mmmm'), 'mmmm'), \
-                      None, \
-                      (u'%s\t%s' % (_('Year (2 digits)'), 'yy'), 'yy'), \
-                      (u'%s\t%s' % (_('Year (4 digits)'), 'yyyy'), 'yyyy'), \
-                      None, \
-                      (u'%s\t%s' % (_('Weekday (1 digit)'), 'w'), 'w'), \
-                      (u'%s\t%s' % (_('Weekday Abbreviation'), 'www'), 'www'), \
+    formatMenuList = [(u'%s\t%s' % (_('Day (1 or 2 digits)'), 'd'), 'd'),
+                      (u'%s\t%s' % (_('Day (2 digits)'), 'dd'), 'dd'),
+                      None,
+                      (u'%s\t%s' % (_('Month (1 or 2 digits)'), 'm'), 'm'),
+                      (u'%s\t%s' % (_('Month (2 digits)'), 'mm'), 'mm'),
+                      (u'%s\t%s' % (_('Month Abbreviation'), 'mmm'), 'mmm'),
+                      (u'%s\t%s' % (_('Month Name'), 'mmmm'), 'mmmm'),
+                      None,
+                      (u'%s\t%s' % (_('Year (2 digits)'), 'yy'), 'yy'),
+                      (u'%s\t%s' % (_('Year (4 digits)'), 'yyyy'), 'yyyy'),
+                      None,
+                      (u'%s\t%s' % (_('Weekday (1 digit)'), 'w'), 'w'),
+                      (u'%s\t%s' % (_('Weekday Abbreviation'), 'www'), 'www'),
                       (u'%s\t%s' % (_('Weekday Name'), 'wwww'), 'wwww')]
     hasEditChoices = True
 
@@ -550,14 +553,14 @@ class DateFormat(TextFormat):
 
     def getEditChoices(self, currentText=''):
         """Return list of choices for combo box, 
-           each a tuple of edit text and annotated text"""
+           each a tuple of edit text and any annotation text"""
         format = globalref.options.strData('EditDateFormat', True)
         today = GenDate().dateStr(format)
         yesterday = (GenDate() - 1).dateStr(format)
         tomorrow = (GenDate() + 1).dateStr(format)
-        return [(today, '%s (%s)' % (today, _('today'))), \
-                (yesterday, '%s (%s)' % (yesterday, _('yesterday'))), \
-                (tomorrow, '%s (%s)' % (tomorrow, _('tomorrow')))]
+        return [(today, '(%s)' %  _('today')),
+                (yesterday, '(%s)' % _('yesterday')),
+                (tomorrow, '(%s)' % _('tomorrow'))]
 
     def getInitDefault(self):
         """Return initial stored value for new nodes"""
@@ -597,23 +600,23 @@ class TimeFormat(TextFormat):
     typeName = 'Time'
     sortSequence = 6
     #field format edit options:
-    defaultFormat = 'h:MM:SS aa'
+    defaultFormat = u'h:MM:SS aa'
     timeStampStrings = ('Now', _('Now', 'time stamp setting'))
-    formatMenuList = [(u'%s\t%s' % (_('Hour (0-23, 1 or 2 digits)'), 'H'), \
-                       'H'), \
-                      (u'%s\t%s' % (_('Hour (00-23, 2 digits)'), 'HH'), 'HH'), \
-                      (u'%s\t%s' % (_('Hour (1-12, 1 or 2 digits)'), 'h'), \
-                       'h'), \
-                      (u'%s\t%s' % (_('Hour (01-12, 2 digits)'), 'hh'), 'hh'), \
-                      None, \
-                      (u'%s\t%s' % (_('Minute (1 or 2 digits)'), 'M'), 'M'), \
-                      (u'%s\t%s' % (_('Minute (2 digits)'), 'MM'), 'MM'), \
-                      None, \
-                      (u'%s\t%s' % (_('Second (1 or 2 digits)'), 'S'), 'S'), \
-                      (u'%s\t%s' % (_('Second (2 digits)'), 'SS'), 'SS'), \
-                      (u'%s\t%s' % (_('Fractional Seconds'), 's'), 's'), \
-                      None, \
-                      (u'%s\t%s' % (_('AM/PM'), 'AA'), 'AA'), \
+    formatMenuList = [(u'%s\t%s' % (_('Hour (0-23, 1 or 2 digits)'), 'H'),
+                       'H'),
+                      (u'%s\t%s' % (_('Hour (00-23, 2 digits)'), 'HH'), 'HH'),
+                      (u'%s\t%s' % (_('Hour (1-12, 1 or 2 digits)'), 'h'),
+                       'h'),
+                      (u'%s\t%s' % (_('Hour (01-12, 2 digits)'), 'hh'), 'hh'),
+                      None,
+                      (u'%s\t%s' % (_('Minute (1 or 2 digits)'), 'M'), 'M'),
+                      (u'%s\t%s' % (_('Minute (2 digits)'), 'MM'), 'MM'),
+                      None,
+                      (u'%s\t%s' % (_('Second (1 or 2 digits)'), 'S'), 'S'),
+                      (u'%s\t%s' % (_('Second (2 digits)'), 'SS'), 'SS'),
+                      (u'%s\t%s' % (_('Fractional Seconds'), 's'), 's'),
+                      None,
+                      (u'%s\t%s' % (_('AM/PM'), 'AA'), 'AA'),
                       (u'%s\t%s' % (_('am/pm'), 'aa'),'aa')]
     hasEditChoices = True
 
@@ -651,10 +654,10 @@ class TimeFormat(TextFormat):
            each a tuple of edit text and annotated text"""
         format = globalref.options.strData('EditTimeFormat', True)
         now = GenTime().timeStr(format)
-        choices = [(now, '%s (%s)' % (now, _('now')))]
+        choices = [(now, '(%s)' % _('now'))]
         for hr in (6, 9, 12, 15, 18, 21, 0):
             time = GenTime((hr, 0)).timeStr(format)
-            choices.append((time, time))
+            choices.append((time, ''))
         return choices
 
     def getInitDefault(self):
@@ -696,10 +699,10 @@ class BooleanFormat(ChoiceFormat):
     sortSequence = 1
     #field format edit options:
     defaultFormat = _('yes/no')
-    formatMenuList = [(_('true/false'), _('true/false')), \
-                      (_('T/F'), _('T/F')), None, \
-                      (_('yes/no'), _('yes/no')), \
-                      (_('Y/N'), _('Y/N')), None, \
+    formatMenuList = [(_('true/false'), _('true/false')),
+                      (_('T/F'), _('T/F')), None,
+                      (_('yes/no'), _('yes/no')),
+                      (_('Y/N'), _('Y/N')), None,
                       ('1/0', '1/0')]
     hasEditChoices = True
 
@@ -742,7 +745,47 @@ class BooleanFormat(ChoiceFormat):
         try:
             return repr(GenBoolean(storedText))
         except GenBooleanError:
-            return '' 
+            return ''
+
+
+class UniqueIDFormat(TextFormat):
+    """An unique ID automatically generated for new nodes"""
+    typeName = 'UniqueID'
+    sortSequence = 10
+    formatRe = re.compile('([^0-9]*)([0-9]+)(.*)')
+    #field format edit options:
+    defaultFormat = u'0001'
+    formatMenuList = [(u'%s\t%s' % (_('Required Digit'), '0'), '0'), None,
+                      (u'%s\t%s' % (_('Start Num Example'), '0100'), '0100'),
+                      (u'%s\t%s' % (_('Prefix Example'), 'id0100'), 'id0100')]
+
+    def __init__(self, name, attrs={}):
+        """Any format, prefix, suffix, html info in attrs dict"""
+        TextFormat.__init__(self, name, attrs)
+
+    def nextValue(self, increment=True):
+        """Return the next value for a new node,
+           increment format if increment is True"""
+        try:
+            prefix, numText, suffix = UniqueIDFormat.formatRe.\
+                                      match(self.format).groups()
+        except AttributeError:
+            self.format = UniqueIDFormat.defaultFormat
+            return self.nextValue(increment)
+        value = self.format
+        if increment:
+            pattern = u'%%s%%0.%dd%%s' % len(numText)
+            num = int(numText) + 1
+            self.format = pattern % (prefix, num, suffix)
+        return value
+
+    def sortValue(self, data):
+        """Return value to be compared for sorting and conditionals"""
+        storedText = data.get(self.name, '')
+        try:
+            return int(UniqueIDFormat.formatRe.match(storedText).group(2))
+        except AttributeError:
+            return 0
 
 
 class URLFormat(TextFormat):
@@ -759,7 +802,7 @@ class URLFormat(TextFormat):
         TextFormat.__init__(self, name, attrs)
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         self.html = True
 
     def outputText(self, item, titleMode, internal=False):
@@ -768,7 +811,7 @@ class URLFormat(TextFormat):
             item = globalref.docRef.fileInfoItem
         altText = ''
         if self.linkAltField:
-            field = item.nodeFormat.findField(self.linkAltField)
+            field = item.nodeFormat().findField(self.linkAltField)
             if field:
                 altText = field.outputText(item, titleMode, internal)
         storedText = item.data.get(self.name, '')
@@ -780,7 +823,7 @@ class URLFormat(TextFormat):
         """Return formatted text, properly escaped and with
            a link reference if not in titleMode"""
         if titleMode:
-            return TextFormat.formatOutput(self, storedText, titleMode, \
+            return TextFormat.formatOutput(self, storedText, titleMode,
                                            internal)
         paths = storedText.split('\n')
         results = []
@@ -788,18 +831,18 @@ class URLFormat(TextFormat):
             path = url
             if not URLFormat.hasMethodRe.match(path):
                 path = u'%s%s' % (self.URLMethod, path)
-            path = u'<a href="%s">%s</a>' % (escape(path, treedoc.escDict), \
+            path = u'<a href="%s">%s</a>' % (escape(path, treedoc.escDict),
                                              altText or url)
-            results.append(TextFormat.formatOutput(self, path, titleMode, \
+            results.append(TextFormat.formatOutput(self, path, titleMode,
                                                    internal))
         return u'<br />'.join(results)
 
     def xslText(self):
         """Return what we need to write into an  XSL file for this type"""
-        return u'<xsl:for-each select = "./%s">%s<xsl:choose>' \
-                '<xsl:when test="contains(., \':\')"><a href="{.}">' \
-                '<xsl:value-of select="."/></a></xsl:when><xsl:otherwise>' \
-                '<a href="%s{.}"><xsl:value-of select="."/></a>' \
+        return u'<xsl:for-each select = "./%s">%s<xsl:choose>'\
+                '<xsl:when test="contains(., \':\')"><a href="{.}">'\
+                '<xsl:value-of select="."/></a></xsl:when><xsl:otherwise>'\
+                '<a href="%s{.}"><xsl:value-of select="."/></a>'\
                 '</xsl:otherwise></xsl:choose>%s</xsl:for-each>' % \
                (self.name, xslEscape(self.prefix), self.URLMethod,
                 xslEscape(self.suffix))
@@ -850,7 +893,7 @@ class ExecuteLinkFormat(URLFormat):
         """Return formatted text, properly escaped and with
            a link reference if not in titleMode"""
         if titleMode or not internal:
-            return TextFormat.formatOutput(self, storedText, titleMode, \
+            return TextFormat.formatOutput(self, storedText, titleMode,
                                            internal)
         paths = storedText.split('\n')
         results = []
@@ -860,7 +903,7 @@ class ExecuteLinkFormat(URLFormat):
             path = url
             if not URLFormat.hasMethodRe.match(path):
                 path = u'%s%s' % (self.URLMethod, path)
-            results.append(u'<a href="%s">%s</a>' % \
+            results.append(u'<a href="%s">%s</a>' %
                            (escape(path, treedoc.escDict), altText or url))
         return u'<br />'.join(results)
 
@@ -881,17 +924,17 @@ class PictureFormat(TextFormat):
         TextFormat.__init__(self, name, attrs)
 
     def initFormat(self):
-        """Called by base init and after class change"""
+        """Called by base init, after class change or format text change"""
         self.html = True
 
     def formatOutput(self, storedText, titleMode, internal=False):
         """Return formatted text, properly escaped and with
            a link to the picture if not in titleMode"""
         if titleMode:
-            return TextFormat.formatOutput(self, storedText, titleMode, \
+            return TextFormat.formatOutput(self, storedText, titleMode,
                                            internal)
         paths = storedText.split('\n')
-        results = ['<img src="%s">' % escape(url, treedoc.escDict) for url \
+        results = ['<img src="%s">' % escape(url, treedoc.escDict) for url
                    in paths]
         return u'<br />'.join(results)
 
@@ -915,14 +958,14 @@ class ParentFormat(TextFormat):
             item = item.parent
             if not item:
                 return ''
-        field = item.nodeFormat.findField(self.name)
+        field = item.nodeFormat().findField(self.name)
         if not field:
             return ''
         return field.outputText(item, titleMode, internal)
 
     def xslText(self):
         """Return what we need to write into an  XSL file for this type"""
-        return u'<xsl:value-of select="%s%s"/>' % (self.parentLevel * '../', \
+        return u'<xsl:value-of select="%s%s"/>' % (self.parentLevel * '../',
                                                    self.name)
 
     def xslTestText(self):
@@ -949,7 +992,7 @@ class AncestorFormat(TextFormat):
         while not field:
             item = item.parent
             if item:
-                field = item.nodeFormat.findField(self.name)
+                field = item.nodeFormat().findField(self.name)
             else:
                 return ''
         return field.outputText(item, titleMode, internal)
@@ -980,7 +1023,7 @@ class ChildFormat(TextFormat):
         """Return formatted text for this field"""
         result = []
         for child in item.childList:
-            field = child.nodeFormat.findField(self.name)
+            field = child.nodeFormat().findField(self.name)
             if field:
                 text = field.outputText(child, titleMode, internal)
                 if text:
@@ -994,3 +1037,21 @@ class ChildFormat(TextFormat):
     def xslTestText(self):
         """Return XSL file test for data existance"""
         return u'normalize-space(child::*/%s)' % self.name
+
+
+class CountFormat(TextFormat):
+    """Placeholder format for a count of children at the given level"""
+    typeName = 'Count'
+
+    def __init__(self, name, level):
+        TextFormat.__init__(self, name, {})
+        self.parentLevel = -level
+
+    def sepName(self, englishOnly=False):
+        """Return name enclosed with {*? *} separators"""
+        name = englishOnly and self.enName or self.name
+        return u'{*#%s*}' % (name)
+
+    def outputText(self, item, titleMode, internal=False):
+        """Return formatted text for this field"""
+        return repr(len(item.descendLevelList(-self.parentLevel)))
