@@ -13,6 +13,7 @@
 #****************************************************************************
 
 
+treeControl = None
 docRef = None
 mainWin = None
 options = None
@@ -35,3 +36,29 @@ updateViewItem = dummyFunction    # called with item parameter
 updateViewMenuStat = dummyFunction
 setStatusBar = dummyFunction  # called with text and optional duration (ms)
 focusTree = dummyFunction
+
+
+def updateRefs(win):
+    """Update references based on current main window"""
+    global mainWin
+    mainWin = win
+    global docRef
+    docRef = mainWin.doc
+    global pluginInterface
+    pluginInterface = mainWin.pluginInterface
+    global updateViewAll
+    updateViewAll = mainWin.updateViews
+    global updateLeftView
+    updateLeftView = mainWin.updateLeftView
+    global updateRightView
+    updateRightView = mainWin.updateRightView
+    global updateViewSelection
+    updateViewSelection = mainWin.updateViewSelection
+    global updateViewItem
+    updateViewItem = mainWin.updateViewItem
+    global updateViewMenuStat
+    updateViewMenuStat = mainWin.updateCmdAvail
+    global setStatusBar
+    setStatusBar = mainWin.setStatusMsg
+    global focusTree
+    focusTree = mainWin.focusLeftView
