@@ -13,13 +13,12 @@
 #*****************************************************************************
 
 import os.path
-from PyQt4 import QtCore, QtGui
-import treedoc
+from PyQt4 import QtGui
 import globalref
 
 class IconDict(dict):
     """Loads and stores icons by name"""
-    iconExt = ['.png', '.bmp']
+    iconExt = ['.png', '.bmp', '.ico', 'gif']
     defaultName = 'default'
     noneName = 'NoIcon'
     def __init__(self):
