@@ -4,7 +4,7 @@
 # optiondefaults.py, provides initial config option values
 #
 # TreeLine, an information storage program
-# Copyright (C) 2006, Douglas W. Bell
+# Copyright (C) 2009, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -61,6 +61,7 @@ menuKeyBindList = [(N_('FileNew'),             'Ctrl+N'),
                    (N_('ViewTitleList'),       'Ctrl+Shift+L'),
                    (N_('ViewShowChild'),       'Ctrl+Shift+C'),
                    (N_('ViewShowDescend'),     'Ctrl+Shift+D'),
+                   (N_('ViewStatusBar'),       ''),
                    (N_('DataSetItemType'),     'Ctrl+T'),
                    (N_('DataSetDescendType'),  ''),
                    (N_('DataConfigType'),      ''),
@@ -90,6 +91,9 @@ menuKeyBindList = [(N_('FileNew'),             'Ctrl+N'),
                    (N_('ToolsDefaultColor'),   ''),
                    (N_('ToolsBackColor'),      ''),
                    (N_('ToolsTextColor'),      ''),
+                   (N_('WinNewWindow'),        ''),
+                   (N_('WinCloseWindow'),      ''),
+                   (N_('WinUpdateWindow'),     'Ctrl+W'),
                    (N_('HelpContents'),        'F1'),
                    (N_('HelpFullReadMe'),      ''),
                    (N_('HelpAbout'),           ''),
@@ -143,8 +147,10 @@ def defaultOutput():
             "AutoFileOpen         no",
             "StartShowChildren    yes",
             "StartShowDescend     no",
+            "ShowStatusBar        yes",
             "PersistTreeState     yes",
             "SaveWindowGeom       yes",
+            "#",
             "ClickRename          yes",
             "DragTree             yes",
             "InsertOnEnter        yes",
@@ -152,6 +158,7 @@ def defaultOutput():
             "OpenSearchNodes      yes",
             "ShowTreeIcons        yes",
             "EnableExecLinks      yes",
+            "OpenNewWindow        yes",
             "CompressNewFiles     no",
             "EncryptNewFiles      no",
             "HtmlNewFields        no",
@@ -237,8 +244,8 @@ def defaultOutput():
             "#",
             "WindowXSize          640",
             "WindowYSize          500",
-            "WindowXPos           0",
-            "WindowYPos           0",
+            "WindowXPos           -1000",
+            "WindowYPos           -1000",
             "TreeSplitPercent     40",
             "OutputSplitPercent   20",
             "EditorSplitPercent   25",
