@@ -51,6 +51,7 @@
 
 import sys
 import os.path
+import tempfile
 from PyQt4 import QtCore, QtGui
 import treedoc
 import nodeformat
@@ -77,6 +78,10 @@ class PluginInterface(object):
             del frame
         return os.path.dirname(fileName)
 
+    def getLanguage(self):
+        """Return language code used by TreeLine for translations"""
+        return globalref.lang
+
     #*************************************************************************
     #  Node Interfaces:
     #*************************************************************************
@@ -427,13 +432,25 @@ class PluginInterface(object):
     #  File Interfaces:
     #*************************************************************************
 
-    def openFile(self, fileRef, importOnFail=True, addToRecent=True):
+    def openFile(self, fileRef, importOnFail=True, addToRecent=True,
+                 newWinOk=True):
         """Open file given by fileRef interactively (QMessageBox on failure),
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined),
            if importOnFail and not a TreeLine file, will prompt for import type,
-           if addToRecent, will add filename to recently used file list"""
-        self.mainWin.openFile(fileRef, importOnFail, addToRecent)
+           if addToRecent, will add filename to recently used file list,
+           if newWinOk will allow to create new window based on user setting"""
+        if hasattr(fileRef, 'read'):
+            fd, fileName = tempfile.mkstemp()
+            os.write(fd, fileRef.read())
+            os.close(fd)
+            fileRef.close()
+        else:
+            fileName = fileRef
+        globalref.treeControl.openFile(fileName, newWinOk, importOnFail,
+                                       addToRecent)
+        if hasattr(fileRef, 'read'):
+            os.remove(fileName)
 
     def newFile(self):
         """Start a new file"""
@@ -457,10 +474,9 @@ class PluginInterface(object):
             return False
 
     def saveFile(self, fileRef):
-        """Save TreeLine file to fileRef interactively (QMessageBox on failure),
-           fileRef is either a file path string or a file-like object
-           (if it is a file-like object, fileRef.name must be defined)"""
-        self.mainWin.saveFile(fileRef)
+        """Save TreeLine file to fileRef interactively
+           (QMessageBox on failure)"""
+        globalref.treeControl.saveFile(fileRef)
 
     def writeFile(self, fileRef, password=''):
         """Save TreeLine file to fileRef non-interactively,
@@ -479,6 +495,23 @@ class PluginInterface(object):
         except IOError:
             return False
 
+    def getFileName(self, caption, defaultExt='', filterList=None,
+                    currentFilter='', saveMode=True):
+        """Return user specified file name for open, save as & export,
+           starts from directory of current or recently used file,
+           caption is the dialog title,
+           defaultExt is added to base file name in saveMode,
+           filterList is a list of filters with extensions (defaults to *.trl),
+           currentFilter is the active filter in saveMode,
+           saveMode is True for save and export, False for file open"""
+        if not filterList:
+            filterList = [self.mainWin.tlGenFileFilter]
+        if saveMode:
+            return self.mainWin.getSaveFileName(caption, defaultExt,
+                                                filterList, currentFilter)
+        else:
+            return self.mainWin.getOpenFileName(caption, filterList)
+
     def getCurrentFileName(self):
         """Return the currently open filename"""
         return globalref.docRef.fileName
@@ -506,6 +539,10 @@ class PluginInterface(object):
         """Set callback function to be called after a file is saved"""
         self.fileSaveCallbacks.append(callbackFunc)
 
+    def fileExport(self):
+        """Export data to html,xml, etc. via dialog and return the fileName"""
+        return self.mainWin.fileExport()
+
     def exportHtml(self, fileRef, includeRoot=True, openOnly=False, indent=20,
                    addHeader=False):
         """Export current branch to single-column HTML,
@@ -521,6 +558,30 @@ class PluginInterface(object):
         except IOError:
             return False
 
+    def exportDirTable(self, dirName, nodeList, addHeader=False):
+        """Export tree to nested directory struct with html tables,
+           dirName is initial export directory,
+           nodeList is list of nodes to export (defaults to selection)"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
+        try:
+            globalref.docRef.exportDirTable(dirName, nodeList, addHeader)
+            return True
+        except IOError:
+            return False
+
+    def exportDirPage(self, dirName, nodeList):
+        """Export tree to nested directory struct with html page for each node,
+           dirName is initial export directory,
+           nodeList is list of nodes to export (defaults to selection)"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
+        try:
+            globalref.docRef.exportDirPage(dirName, nodeList)
+            return True
+        except IOError:
+            return False
+
     def exportXslt(self, fileRef, includeRoot=True, indent=20):
         """Export XSLT file for the current formatting,
            fileRef is either a file path string or a file-like object
@@ -533,71 +594,108 @@ class PluginInterface(object):
         except IOError:
             return False
 
-    def exportTrlSubtree(self, fileRef):
+    def exportTrlSubtree(self, fileRef, nodeList, addBranches=True):
         """Export current branch as a TreeLine subtree,
            fileRef is either a file path string or a file-like object
-           (if it is a file-like object, fileRef.name must be defined)
+           (if it is a file-like object, fileRef.name must be defined),
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportTrlSubtree(fileRef, [self.getCurrentNode()])
+            globalref.docRef.exportTrlSubtree(fileRef, nodeList, addBranches)
             return True
         except IOError:
             return False
 
-    def exportTable(self, fileRef):
+    def exportTable(self, fileRef, nodeList, addBranches=True):
         """Export current item's children as a table of data,
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportTable(fileRef, [self.getCurrentNode()])
+            globalref.docRef.exportTable(fileRef, nodeList, addBranches)
             return True
         except IOError:
             return False
 
-    def exportTabbedTitles(self, fileRef, includeRoot=True, openOnly=False):
+    def exportTabbedTitles(self, fileRef, nodeList, addBranches=True,
+                           includeRoot=True, openOnly=False):
         """Export current branch to tabbed text titles,
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportTabbedTitles(fileRef,
-                                                [self.getCurrentNode()],
-                                                True, includeRoot, openOnly)
+            globalref.docRef.exportTabbedTitles(fileRef, nodeList, addBranches,
+                                                includeRoot, openOnly)
             return True
         except IOError:
             return False
 
-    def exportXbelBookmarks(self, fileRef):
+    def exportXbelBookmarks(self, fileRef, nodeList, addBranches=True):
         """Export current branch to XBEL format bookmarks,
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportXbel(fileRef, [self.getCurrentNode()])
+            globalref.docRef.exportXbel(fileRef, nodeList, addBranches)
             return True
         except IOError:
             return False
 
-    def exportHtmlBookmarks(self, fileRef):
+    def exportHtmlBookmarks(self, fileRef, nodeList, addBranches=True):
         """Export current branch to HTML format bookmarks,
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportHtmlBookmarks(fileRef,
-                                                 [self.getCurrentNode()])
+            globalref.docRef.exportHtmlBookmarks(fileRef, nodeList,
+                                                 addBranches)
             return True
         except IOError:
             return False
 
-    def exportGenericXml(self, fileRef):
+    def exportGenericXml(self, fileRef, nodeList, addBranches=True):
         """Export current branch to generic XML (non-TreeLine) file,
            fileRef is either a file path string or a file-like object
            (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
            returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
         try:
-            globalref.docRef.exportGenericXml(fileRef, [self.getCurrentNode()])
+            globalref.docRef.exportGenericXml(fileRef, nodeList, addBranches)
+            return True
+        except IOError:
+            return False
+
+    def exportOdf(self, fileRef, nodeList, addBranches=True,
+                  includeRoot=True, openOnly=False):
+        """Export an ODF format text file,
+           fileRef is either a file path string or a file-like object
+           (if it is a file-like object, fileRef.name must be defined)
+           nodeList is list of nodes to export (defaults to selection),
+           returns True on success, False on failure"""
+        if not nodeList:
+            nodeList = self.getSelectedNodes()
+        fontInfo = QtGui.QFontInfo(self.mainWin.dataOutSplit.widget(0).font())
+        try:
+            globalref.docRef.exportOdf(fileRef, nodeList, fontInfo.family(),
+                                       fontInfo.pointSize(),
+                                       fontInfo.fixedPitch(), addBranches,
+                                       includeRoot, openOnly)
             return True
         except IOError:
             return False
