@@ -11,7 +11,6 @@
 # but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
 #*****************************************************************************
 
-import sys
 import re
 import copy
 from PyQt4 import QtCore, QtGui
@@ -98,6 +97,7 @@ class PrintPrevDlg(QtGui.QDialog):
     def showOptions(self):
         """Show a modal options dialog"""
         dlg = PrintOptionsDialog(self.printData, False, self)
+        self.setUpdatesEnabled(False)  # halt repaint until settings consistent
         if dlg.exec_() == QtGui.QDialog.Accepted:
             QtGui.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)
             self.printData.setPrintContent()
@@ -109,6 +109,7 @@ class PrintPrevDlg(QtGui.QDialog):
             self.preview.paperRect = self.printData.printer.paperRect()
             self.updatePageNum()
             QtGui.QApplication.restoreOverrideCursor()
+        self.setUpdatesEnabled(True)
 
 
 class PrintPrev(QtGui.QWidget):
