@@ -189,6 +189,7 @@ class TreeControl(object):
         except treedoc.ReadFileError, e:
             QtGui.QApplication.restoreOverrideCursor()
             if not importOnFail:
+                globalref.updateRefs(oldWin)
                 return True
             # assume file is not a TreeLine file
             importType = self.chooseImportType()
@@ -206,7 +207,7 @@ class TreeControl(object):
             win.fileImported = True
         win.doc.root.open = True
         QtGui.QApplication.restoreOverrideCursor()
-        if win is not oldWin:
+        if win not in self.windowList:
             self.windowList.append(win)
         win.updateForFileChange(addToRecent)
         if win.pluginInterface:
