@@ -12,7 +12,6 @@
 # but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
 #*****************************************************************************
 
-import copy
 import re
 import string
 import os
@@ -168,7 +167,6 @@ class TypeSetDlg(QtGui.QDialog):
                 if type not in typeList:
                     typeList.append(type)
         if len(typeList) > 1:
-            caption = _('Select Type')
             type, ok = QtGui.QInputDialog.getItem(self, _('Select Type'),
                                                   _('Change from data type'),
                                                   typeList, 0, False)
@@ -205,6 +203,7 @@ class TypeSetDlg(QtGui.QDialog):
 
     def closeEvent(self, event):
         """Signal that view is closing"""
+        self.hide()
         self.emit(QtCore.SIGNAL('viewClosed'), False)
         event.accept()
 
@@ -304,19 +303,14 @@ class FieldSelectList(QtGui.QTreeWidget):
 
 class SortDlg(QtGui.QDialog):
     """Dialog to control sorting options"""
-    entireTree = 0
-    selectBranch = 1
-    selectChildren = 2
-    selectSiblings = 3
+    entireTree, selectBranch, selectChildren, selectSiblings = range(4)
     sortWhat = selectBranch
-    allTypes = 0
-    chooseTypes = 1
-    titlesAscend = 2
-    titlesDescend = 3
+    allTypes, chooseTypes, titlesAscend, titlesDescend = range(4)
     method = allTypes
     def __init__(self, parent=None):
         QtGui.QDialog.__init__(self, parent)
-        self.setWindowFlags(stdWinFlags)
+        self.setAttribute(QtCore.Qt.WA_QuitOnClose, False)
+        self.setWindowFlags(QtCore.Qt.Window)
         self.setWindowTitle(_('Sorting'))
 
         topLayout = QtGui.QGridLayout(self)
@@ -563,6 +557,7 @@ class SortDlg(QtGui.QDialog):
 
     def closeEvent(self, event):
         """Signal that view is closing"""
+        self.hide()
         self.emit(QtCore.SIGNAL('viewClosed'), False)
         event.accept()
 
@@ -841,20 +836,10 @@ class TemplateDialog(QtGui.QDialog):
 
 class ExportDlg(QtGui.QDialog):
     """Dialog for selecting type of file export"""
-    htmlType = 0
-    dirType = 1
-    xsltType = 2
-    trlType = 3
-    textType = 4
-    tableType = 5
-    xbelType = 6
-    mozType = 7
-    xmlType = 8
-    odfType = 9
+    htmlType, dirTableType, dirPageType, xsltType, trlType, textType, \
+              tableType, xbelType, mozType, xmlType, odfType = range(11)
     exportType = htmlType
-    entireTree = 0
-    selectBranch = 1
-    selectNode = 2
+    entireTree, selectBranch, selectNode = range(3)
     exportWhat = entireTree
     includeRoot = False
     openOnly = False
@@ -875,9 +860,12 @@ class ExportDlg(QtGui.QDialog):
         htmlButton = QtGui.QRadioButton(_('&HTML single file output'))
         self.typeButtons.addButton(htmlButton, ExportDlg.htmlType)
         typeLayout.addWidget(htmlButton)
-        dirButton = QtGui.QRadioButton(_('HTML &directories output'))
-        self.typeButtons.addButton(dirButton, ExportDlg.dirType)
+        dirButton = QtGui.QRadioButton(_('HTML &directory tables'))
+        self.typeButtons.addButton(dirButton, ExportDlg.dirTableType)
         typeLayout.addWidget(dirButton)
+        dirPageButton = QtGui.QRadioButton(_('HTML directory &pages'))
+        self.typeButtons.addButton(dirPageButton, ExportDlg.dirPageType)
+        typeLayout.addWidget(dirPageButton)
         xsltButton = QtGui.QRadioButton(_('&XSLT output'))
         self.typeButtons.addButton(xsltButton, ExportDlg.xsltType)
         typeLayout.addWidget(xsltButton)
@@ -983,13 +971,14 @@ class ExportDlg(QtGui.QDialog):
         else:
             self.openOnlyButton.setChecked(False)
             self.openOnlyButton.setEnabled(False)
-        if exportType in (ExportDlg.htmlType, ExportDlg.dirType):
+        if exportType in (ExportDlg.htmlType, ExportDlg.dirTableType):
             self.headerButton.setEnabled(True)
         else:
             self.headerButton.setChecked(False)
             self.headerButton.setEnabled(False)
         if exportType == ExportDlg.htmlType:
             self.colLabel.setEnabled(True)
+            self.numColSpin.setEnabled(True)
         else:
             self.numColSpin.setValue(1)
             self.numColSpin.setEnabled(False)
@@ -1006,7 +995,8 @@ class ExportDlg(QtGui.QDialog):
             self.whatButtons.button(ExportDlg.entireTree).setChecked(True)
         else:
             self.whatButtons.button(ExportDlg.selectBranch).setEnabled(True)
-        if exportType in (ExportDlg.dirType, ExportDlg.xsltType):
+        if exportType in (ExportDlg.dirTableType, ExportDlg.dirPageType,
+                          ExportDlg.xsltType):
             self.whatButtons.button(ExportDlg.selectNode).setEnabled(False)
             if self.whatButtons.checkedId() == ExportDlg.selectNode:
                 self.whatButtons.button(ExportDlg.selectBranch).\
@@ -1032,9 +1022,7 @@ class ExportDlg(QtGui.QDialog):
 
 class NumberingDlg(QtGui.QDialog):
     """Dialog for adding numbering to nodes"""
-    outlineType = 0
-    sectionType = 1
-    singleType = 2
+    outlineType, sectionType, singleType = range(3)
     outlineFormat = ['I.', 'A.', '1.', 'a)', '(1)', '(a)', '(i)']
     sectionFormat = ['1', '.1', '.1']
     singleFormat = ['1.']
@@ -1234,6 +1222,8 @@ class FindTextEntry(QtGui.QDialog):
         self.entry = QtGui.QLineEdit()
         topLayout.addWidget(self.entry)
         self.entry.setFocus()
+        self.statusLabel = QtGui.QLabel()
+        topLayout.addWidget(self.statusLabel)
         ctrlLayout = QtGui.QHBoxLayout()
         topLayout.addLayout(ctrlLayout)
         ctrlLayout.addStretch(0)
@@ -1262,8 +1252,9 @@ class FindTextEntry(QtGui.QDialog):
                 if rightSplitter == globalref.mainWin.dataOutSplit and \
                         rightView.height():
                     rightView.highlightWords(wordList)
+                self.statusLabel.setText('')
             else:
-                globalref.setStatusBar(_('Text string not found'), 4000)
+                self.statusLabel.setText(_('Text string not found'))
 
     def findNext(self):
         """Find next match"""
@@ -1281,6 +1272,7 @@ class FindTextEntry(QtGui.QDialog):
 
     def closeEvent(self, event):
         """Signal that view is closing"""
+        self.hide()
         self.emit(QtCore.SIGNAL('viewClosed'), False)
         event.accept()
 
@@ -1651,6 +1643,10 @@ class ShortcutDlg(QtGui.QDialog):
 
         ctrlLayout = QtGui.QHBoxLayout()
         topLayout.addLayout(ctrlLayout)
+        defaultButton = QtGui.QPushButton(_('Restore Defaults'))
+        ctrlLayout.addWidget(defaultButton)
+        self.connect(defaultButton, QtCore.SIGNAL('clicked()'),
+                     self.restoreDefaults)
         ctrlLayout.addStretch(0)
         okButton = QtGui.QPushButton(_('&OK'))
         ctrlLayout.addWidget(okButton)
@@ -1682,6 +1678,11 @@ class ShortcutDlg(QtGui.QDialog):
         viewport.adjustSize()
         return scrollArea
 
+    def restoreDefaults(self):
+        """Set toolbars back to default settings"""
+        for edit in self.editList:
+            edit.loadKey(True)
+
     def accept(self):
         """Save changes to options and update actions before closing"""
         for edit in self.editList:
@@ -1699,7 +1700,12 @@ class KeyLineEdit(QtGui.QLineEdit):
         self.dialogRef = dialogRef
         self.setReadOnly(True)
         self.modified = False
-        keyName = globalref.options.strData(self.command, True)
+        self.key = None
+        self.loadKey()
+
+    def loadKey(self, defaultOnly=False):
+        """Load key shortcut"""
+        keyName = globalref.options.strData(self.command, True, defaultOnly)
         if keyName:
             keyName = '+'.join(keyName.split())  # for legacy config files
             self.key = QtGui.QKeySequence(keyName)
@@ -1707,6 +1713,8 @@ class KeyLineEdit(QtGui.QLineEdit):
         else:
             self.key = None
             self.setText(KeyLineEdit.blankText)
+        if defaultOnly:
+            self.modified = True
 
     def clearKey(self):
         """Remove existing key"""
@@ -1792,12 +1800,9 @@ class ToolbarDlg(QtGui.QDialog):
         self.updateFunction = updateFunction
         self.toolIcons = toolIcons
         self.modified = False
-        self.numToolbars = globalref.options.intData('ToolbarQuantity', 0,
-                                                 optiondefaults.maxNumToolbars)
+        self.numToolbars = 0
         self.availableCommands = []
-        self.toolbarLists = [globalref.options.
-                             strData('Toolbar%d' % num, True).split(',') for
-                             num in range(self.numToolbars)]
+        self.toolbarLists = []
 
         topLayout = QtGui.QVBoxLayout(self)
         gridLayout = QtGui.QGridLayout()
@@ -1819,14 +1824,13 @@ class ToolbarDlg(QtGui.QDialog):
         numberBox = QtGui.QGroupBox(_('Toolbar Quantity'))
         gridLayout.addWidget(numberBox, 0, 2)
         numberLayout = QtGui.QHBoxLayout(numberBox)
-        numberSpin = QtGui.QSpinBox()
-        numberLayout.addWidget(numberSpin)
-        numberSpin.setRange(0, optiondefaults.maxNumToolbars)
-        numberSpin.setValue(self.numToolbars)
+        self.quantitySpin = QtGui.QSpinBox()
+        numberLayout.addWidget(self.quantitySpin)
+        self.quantitySpin.setRange(0, optiondefaults.maxNumToolbars)
         numberlabel = QtGui.QLabel(_('&Toolbars'))
         numberLayout.addWidget(numberlabel)
-        numberlabel.setBuddy(numberSpin)
-        self.connect(numberSpin, QtCore.SIGNAL('valueChanged(int)'),
+        numberlabel.setBuddy(self.quantitySpin)
+        self.connect(self.quantitySpin, QtCore.SIGNAL('valueChanged(int)'),
                      self.changeQuantity)
 
         availableBox = QtGui.QGroupBox(_('A&vailable Commands'))
@@ -1848,7 +1852,6 @@ class ToolbarDlg(QtGui.QDialog):
 
         self.availableListWidget = QtGui.QListWidget()
         availableLayout.addWidget(self.availableListWidget)
-        self.updateAvailableCommands(menuCombo.currentText())
 
         buttonLayout = QtGui.QVBoxLayout()
         gridLayout.addLayout(buttonLayout, 1, 1)
@@ -1869,7 +1872,6 @@ class ToolbarDlg(QtGui.QDialog):
         toolbarLayout = QtGui.QVBoxLayout(toolbarBox)
         self.toolbarCombo = QtGui.QComboBox()
         toolbarLayout.addWidget(self.toolbarCombo)
-        # self.updateToolbarCombo()
         self.connect(self.toolbarCombo,
                      QtCore.SIGNAL('currentIndexChanged(int)'),
                      self.updateToolbarCommands)
@@ -1891,11 +1893,12 @@ class ToolbarDlg(QtGui.QDialog):
         self.connect(self.moveDownButton, QtCore.SIGNAL('clicked()'),
                      self.moveDown)
 
-        self.updateToolbarCombo()
-        self.updateToolbarCommands(0)
-
         ctrlLayout = QtGui.QHBoxLayout()
         topLayout.addLayout(ctrlLayout)
+        defaultButton = QtGui.QPushButton(_('Restore Defaults'))
+        ctrlLayout.addWidget(defaultButton)
+        self.connect(defaultButton, QtCore.SIGNAL('clicked()'),
+                     self.restoreDefaults)
         ctrlLayout.addStretch(0)
         okButton = QtGui.QPushButton(_('&OK'))
         ctrlLayout.addWidget(okButton)
@@ -1911,6 +1914,11 @@ class ToolbarDlg(QtGui.QDialog):
         self.connect(cancelButton, QtCore.SIGNAL('clicked()'),
                      self, QtCore.SLOT('reject()'))
 
+        self.loadToolbars()
+        self.updateAvailableCommands(menuCombo.currentText())
+        self.updateToolbarCombo()
+        self.updateToolbarCommands(0)
+
     def translatedCommand(self, command):
         """Return command translated and with spaces added"""
         text = optiondefaults.cmdTranslationDict[command]
@@ -1966,6 +1974,19 @@ class ToolbarDlg(QtGui.QDialog):
                               self.availableListWidget)
         self.availableListWidget.setCurrentRow(0)
 
+    def loadToolbars(self, defaultOnly=False):
+        """Load toolbar data from options"""
+        self.numToolbars = globalref.options.intData('ToolbarQuantity', 0,
+                                                 optiondefaults.maxNumToolbars,
+                                                 defaultOnly)
+        self.quantitySpin.blockSignals(True)
+        self.quantitySpin.setValue(self.numToolbars)
+        self.quantitySpin.blockSignals(False)
+        self.toolbarLists = [globalref.options.
+                             strData('Toolbar%d' % num, True, defaultOnly).
+                             split(',')
+                             for num in range(self.numToolbars)]
+
     def updateToolbarCombo(self):
         """Fill in toolbar numbers for current toolbar quantity"""
         self.toolbarCombo.clear()
@@ -2048,6 +2069,13 @@ class ToolbarDlg(QtGui.QDialog):
         self.toolbarLists[toolNum].insert(pos + 1, command)
         self.setModified()
 
+    def restoreDefaults(self):
+        """Set toolbars back to default settings"""
+        self.loadToolbars(True)
+        self.updateToolbarCombo()
+        self.updateToolbarCommands(0)
+        self.setModified()
+
     def applyChanges(self):
         """Apply any changes from the dialog"""
         if self.sizeCombo.currentIndex() == 0:
