@@ -17,19 +17,14 @@ import os.path
 import tempfile
 from PyQt4 import QtCore, QtGui
 import configdialog
-import treedoc
+import treemainwin
 import optiondefaults
 import globalref
 
 
 class DataEditLine(QtGui.QTextEdit):
     """Line editor within data edit view"""
-    tagMenuEntries = [(_('&Bold'), ('<b>', '</b>')),
-                      (_('&Italics'), ('<i>', '</i>')),
-                      (_('&Underline'), ('<u>', '</u>')),
-                      (_('&Size...'), ('<font size="%s">', '</font>')),
-                      (_('&Color...'), ('<font color="%s">', '</font>'))]
-    tagDict = dict(tagMenuEntries)
+    fileBrowsePath = ''
     def __init__(self, field, item, labelRef, parent=None):
         QtGui.QTextEdit.__init__(self, parent)
         self.field = field
@@ -76,12 +71,15 @@ class DataEditLine(QtGui.QTextEdit):
         """Open file browser to set contents"""
         dfltPath = unicode(self.toPlainText()).strip()
         if not dfltPath or not os.path.exists(dfltPath):
-            dfltPath = os.path.dirname(globalref.docRef.fileName)
+            dfltPath = DataEditLine.fileBrowsePath
+            if not dfltPath or not os.path.exists(dfltPath):
+                dfltPath = os.path.dirname(globalref.docRef.fileName)
         fileName = unicode(QtGui.QFileDialog.getOpenFileName(self,
                                                     _('Browse for file name'),
                                                     dfltPath,
                                                     '%s (*)' % _('All Files')))
         if fileName:
+            DataEditLine.fileBrowsePath = os.path.dirname(fileName)
             if ' ' in fileName and self.field.typeName == u'ExecuteLink':
                 fileName = "'%s'" % fileName
             self.setPlainText(fileName)
@@ -175,6 +173,10 @@ class DataEditLine(QtGui.QTextEdit):
         cursor.setPosition(selectEnd, QtGui.QTextCursor.KeepAnchor)
         self.setTextCursor(cursor)
 
+    def addHtmlLinkTag(self, ref, text):
+        """Add HTML inline internal link with given text"""
+        self.insertPlainText('<a href="#%s">%s</a>' % (ref, text))
+
     def contextMenuEvent(self, event):
         """Override popup menu to add tag submenu, ext editor and config
            modification menu items"""
@@ -185,6 +187,10 @@ class DataEditLine(QtGui.QTextEdit):
         self.connect(extEditAct, QtCore.SIGNAL('triggered()'),
                      self.showExtEditor)
         menu.insertMenu(firstAction, globalref.mainWin.tagSubMenu)
+        addLinkAct = QtGui.QAction(_('&Add Internal Link...'), self)
+        menu.insertAction(firstAction, addLinkAct)
+        self.connect(addLinkAct, QtCore.SIGNAL('triggered()'),
+                     globalref.mainWin.inlineLinkTagPrompt)
         menu.insertSeparator(firstAction)
         typeConfigAct = QtGui.QAction(_('&Modify Type Config...'), self)
         menu.insertAction(firstAction, typeConfigAct)
@@ -213,7 +219,6 @@ class DataEditLine(QtGui.QTextEdit):
         else:
             maxNumLines = globalref.options.intData('MaxEditLines', 1,
                                                     optiondefaults.maxNumLines)
-            maxHeight = maxNumLines * lineHeight
             textRect = fontMetrics.boundingRect(0, 0, width - \
                                                 DataEditGroup.horizMargins,
                                                 100000, QtCore.Qt.TextWordWrap,
@@ -444,8 +449,8 @@ class DataEditGroup(QtGui.QGroupBox):
         configdialog.ConfigDialog.currentField = globalref.docRef.\
                                        treeFormats[self.item.formatName].\
                                        fieldList[0].name
-        globalref.mainWin.configDlg.tabs.setCurrentIndex(1)
-        globalref.mainWin.configDlg.updatePage()
+        treemainwin.TreeMainWin.configDlg.tabs.setCurrentIndex(1)
+        treemainwin.TreeMainWin.configDlg.updatePage()
 
     def modifyFieldConfig(self):
         """Bring up type config dialog with the caller's field"""
@@ -453,8 +458,8 @@ class DataEditGroup(QtGui.QGroupBox):
         globalref.mainWin.dataConfig(True)
         configdialog.ConfigDialog.currentType = self.item.formatName
         configdialog.ConfigDialog.currentField = field
-        globalref.mainWin.configDlg.tabs.setCurrentIndex(3)
-        globalref.mainWin.configDlg.updatePage()
+        treemainwin.TreeMainWin.configDlg.tabs.setCurrentIndex(3)
+        treemainwin.TreeMainWin.configDlg.updatePage()
 
 class DataEditScrollView(QtGui.QScrollArea):
     """Right pane view to edit database info"""
@@ -590,7 +595,7 @@ class DataEditView(QtGui.QWidget):
         self.scrollView.replaceGroups(self.allItems[start:end])
         self.updateControl()
         self.show()
-        globalref.focusTree()
+        self.scrollView.dataGroups[0].setFocus(QtCore.Qt.TabFocusReason)
 
     def viewForward(self):
         """View next set of groups"""
@@ -601,7 +606,7 @@ class DataEditView(QtGui.QWidget):
         self.shownRanges.append((start, start + numGroups))
         self.updateControl()
         self.show()
-        globalref.focusTree()
+        self.scrollView.dataGroups[0].setFocus(QtCore.Qt.TabFocusReason)
 
     def viewAll(self):
         """View all groups"""
@@ -648,11 +653,20 @@ class DataEditView(QtGui.QWidget):
     def scrollPage(self, numPages=1):
         """Scrolls down by numPages (negative for up)
            leaving a one-line overlap"""
-        delta = self.scrollView.maximumViewportSize().height() - \
-                self.fontMetrics().height()
-        if delta > 0:
-            scrollBar = self.scrollView.verticalScrollBar()
+        delta = self.scrollView.maximumViewportSize().height()
+        if delta == 0:
+            return
+        fontSize = self.fontMetrics().height()
+        if delta > fontSize:
+            delta -= fontSize
+        scrollBar = self.scrollView.verticalScrollBar()
+        if (numPages > 0 and scrollBar.value() < scrollBar.maximum()) or \
+                (numPages < 0 and scrollBar.value() > scrollBar.minimum()):
             scrollBar.setValue(scrollBar.value() + numPages * delta)
+        elif numPages < 0:
+            self.viewBack()
+        else:
+            self.viewForward()
 
     def resizeEvent(self, event):
         """Change the minimum viewport size if view size changes"""
