@@ -164,7 +164,7 @@ class TreeItem(object):
             if not globalref.docRef.formHtml:
                 xmlList[0] += u' nohtml="y"'
             if globalref.docRef.childFieldSep != \
-                                globalref.docRef.childFieldSepDflt:
+                                treedoc.TreeDoc.childFieldSepDflt:
                 xmlList[0] += u' childsep="%s"' % \
                               escape(globalref.docRef.childFieldSep,
                                      treedoc.escDict)
@@ -222,7 +222,7 @@ class TreeItem(object):
                 textList.extend(child.exportToText(level + 1, openOnly))
         return textList
 
-    def exportDir(self, linkDict, parentTitle=None, header='', footer=''):
+    def exportDirTable(self, linkDict, parentTitle=None, header='', footer=''):
         """Write dir structure with html tables"""
         if not self.childList:
             return
@@ -233,7 +233,7 @@ class TreeItem(object):
             os.chdir(dirName)
         except (OSError, ValueError, UnicodeError):
             print 'Error - cannot create directory', dirName
-            raise IOError(_('Error - cannot create directory %s' % dirName))
+            raise IOError(_('Error - cannot create directory %s') % dirName)
         title = self.title()
         lines = [u'<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 '\
                  'Transitional//EN">', u'<html>', u'<head>',
@@ -260,7 +260,8 @@ class TreeItem(object):
                     anchor = match.group(1)
                     absPath = linkDict.get(anchor, '')
                     if absPath:
-                        relPath = treedoc.relativePath(os.getcwd(), absPath)
+                        curPath = unicode(dirName, sys.getfilesystemencoding())
+                        relPath = treedoc.relativePath(curPath, absPath)
                         relPath = os.path.join(relPath, 'index.html')
                         if os.sep != '/':
                             relPath = relPath.replace(os.sep, '/')
@@ -283,29 +284,125 @@ class TreeItem(object):
             f = codecs.open('index.html', 'w', 'utf-8')
             f.writelines([line + '\n' for line in lines])
         except IOError:
-            print 'Error - could not write file to', dirname
-            raise IOError(_('Error - cannot write file to %s' % dirName))
+            print 'Error - could not write file to', dirName
+            raise IOError(_('Error - cannot write file to %s') % dirName)
         f.close()
         for child in self.childList:
-            child.exportDir(linkDict, title, header, footer)
+            child.exportDirTable(linkDict, title, header, footer)
         os.chdir('..')
 
-    def createDirLinkDict(self, linkDict, path):
+    def createDirTableLinkDict(self, linkDict, path):
         """Create dict to store parent directories for internal links"""
         for anchor in filter(None, self.refFieldText().split('\n')):
             linkDict[anchor] = path
-        path = os.path.join(path, self.exportDirName(True))
+        path = os.path.join(path, self.exportDirName(False))
         for child in self.childList:
-            child.createDirLinkDict(linkDict, path)
+            child.createDirTableLinkDict(linkDict, path)
+
+    def exportDirPage(self, linkDict, level=0):
+        """Write directory structure with navigation bar and full pages"""
+        title = self.title()
+        lines = [u'<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 '\
+                  'Transitional//EN">', u'<html>', u'<head>',
+                 u'<meta http-equiv="Content-Type" content="text/html; '\
+                  'charset=utf-8">',
+                 u'<link rel="stylesheet" type="text/css" '\
+                   'href="%sdefault.css" />' % ('../' * level),
+                 u'<title>%s</title>' % title,
+                 u'</head>', u'<body>', u'<div id="sidebar">']
+        links = []
+        for item in self.childList:
+            links.append(u'&nbsp; &nbsp; &nbsp; &nbsp; &bull; '\
+                          '<a href="%s/%s.html">%s</a><br />' %
+                         (self.exportDirName(False), item.exportDirName(False),
+                          item.title()))
+        uncleList = []
+        if self.parent and level > 0:
+            siblingList = self.parent.childList
+            if self.parent.parent and level > 1:
+                uncleList = self.parent.parent.childList
+            else:
+                uncleList = [self.parent]
+        else:
+            siblingList = [self]
+        pos = 0
+        for item in siblingList:
+            if item is self:
+                links.insert(pos, u'&nbsp; &nbsp; &bull; <b>%s</b><br />' %
+                             self.title())
+                pos = len(links)
+            else:
+                links.insert(pos,
+                             u'&nbsp; &nbsp; &bull; '\
+                              '<a href="%s.html">%s</a><br />' %
+                             (item.exportDirName(False), item.title()))
+            pos += 1
+        pos = 0
+        for item in uncleList:
+            links.insert(pos,
+                         u'&bull; <a href="../%s.html">%s</a><br />' %
+                         (item.exportDirName(False), item.title()))
+            if item is self.parent:
+                pos = len(links)
+            pos += 1
+        lines.extend(links)
+        lines.append('</div>')
+        textList = []
+        for line in self.formatText(True, True, True):
+            for match in TreeItem.dirExportLinkRe.finditer(line):
+                anchor = match.group(1)
+                absPath = linkDict.get(anchor, '')
+                if absPath:
+                    curPath = unicode(os.getcwd(), sys.getfilesystemencoding())
+                    relPath = treedoc.relativePath(curPath, absPath)
+                    if os.sep != '/':
+                        relPath = relPath.replace(os.sep, '/')
+                    link = '<a href="%s">' % relPath
+                    line = TreeItem.dirExportLinkRe.sub(link, line)
+            textList.append(line)
+        sep = globalref.docRef.lineBreaks and u'<br />\n' or u'\n'
+        lines.append(sep.join(textList))
+        lines.extend([u'</body>', u'</html>'])
+        dirName = self.exportDirName(True)
+        fileName = '%s.html' % dirName
+        try:
+            f = codecs.open(fileName, 'w', 'utf-8')
+            f.writelines([line + '\n' for line in lines])
+        except (IOError, UnicodeError):
+            print 'Error - could not write file to %s', fileName
+            raise IOError(_('Error - cannot write file to %s') % fileName)
+        f.close()
+        if self.childList:
+            try:
+                if not os.access(dirName, os.R_OK):
+                    os.mkdir(dirName, 0755)
+                os.chdir(dirName)
+            except (OSError, ValueError, UnicodeError):
+                print 'Error - cannot create directory', dirName
+                raise IOError(_('Error - cannot create directory %s')
+                              % dirName)
+            for child in self.childList:
+                child.exportDirPage(linkDict, level + 1)
+            os.chdir('..')
+
+    def createDirPageLinkDict(self, linkDict, path):
+        """Create dict to store parent directories for internal links"""
+        dirName = self.exportDirName(False)
+        for anchor in filter(None, self.refFieldText().split('\n')):
+            linkDict[anchor] = os.path.join(path, '%s.html' % dirName)
+        path = os.path.join(path, dirName)
+        for child in self.childList:
+            child.createDirPageLinkDict(linkDict, path)
 
     def exportDirName(self, encode=False):
-        """Return legal directory name for exportDir()"""
+        """Return legal directory name for exporting to directories"""
         try:
             dirName = filter(None, self.refFieldText().split('\n'))[0]
         except IndexError:
             dirName = ''
-        if encode:
-            dirName = dirName.encode(sys.getfilesystemencoding(), 'replace')
+        dirName = dirName.encode(sys.getfilesystemencoding(), 'replace')
+        if not encode:
+            dirName = unicode(dirName, sys.getfilesystemencoding())
         dirName = TreeItem.dirExportDirRe.sub('', dirName)
         if not dirName:
             dirName = '___'
@@ -778,7 +875,7 @@ class TreeItem(object):
             childOfTypeList.sort(self.cmpItems)
             if len(childOfTypeList) < len(self.childList):
                 childOfTypeList.extend([child for child in self.childList
-                                        if child.formatName not in formatName])
+                                       if child.formatName not in formatNames])
             self.childList = childOfTypeList
 
     def sortTypeBranch(self, formatNames):
@@ -818,8 +915,13 @@ class TreeItem(object):
 
     def editFields(self, valueDict):
         """Set values for fields based on dictionary"""
-        for field in valueDict.keys():
-            self.data[field] = valueDict[field]
+        for fieldName, value in valueDict.iteritems():
+            field = self.nodeFormat().findField(fieldName)
+            if field:
+                newValue, ok = field.storedText(value)
+                if ok:
+                    value = newValue
+            self.data[fieldName] = value
         globalref.docRef.modified = True
 
     def childTypes(self):
@@ -935,7 +1037,6 @@ class TreeItem(object):
         self.childList = [item for item in self.descendantGen() if not
                           item.childList]
         for item in self.childList:
-            fieldList = item.nodeFormat().fieldNames()
             origFields = origTreeFormats[item.formatName].fieldNames()
             addedFields = []
             oldParent = item.parent
