@@ -4,80 +4,159 @@
 # treeselection.py, stores and controls node selections for TreeLine
 #
 # TreeLine, an information storage program
-# Copyright (C) 2005, Douglas W. Bell
+# Copyright (C) 2006, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
-# terms of the GNU General Public License, Version 2.  This program is
-# distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
+# terms of the GNU General Public License, either Version 2 or any later
+# version.  This program is distributed in the hope that it will be useful,
+# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
 #****************************************************************************
 
 import globalref
 
 class TreeSelection(list):
     """A list for tree node selections"""
+    maxHistoryLength = 100
     def __init__(self, initList=[]):
         list.__init__(self, initList)
         self.currentItem = None  # set by GUI when changed
         if self:
             self.currentItem = self[-1]
         self.searchOpenList = []
+        self.prevSelects = []
+        self.nextSelects = []
 
     def __getslice__(self, i, j):
         """Modified to copy object with slice"""
         result = TreeSelection(list.__getslice__(self, i, j))
         result.currentItem = self.currentItem
         result.searchOpenList = self.searchOpenList[:]
+        result.prevSelects = self.prevSelects[:]
+        result.nextSelects = self.nextSelects[:]
         return result
 
     def change(self, selectList):
         """Replace selection with items in list and update view"""
+        self.addToHistory()
         self[:] = selectList
         globalref.updateViewSelection()
 
     def replace(self, selectList):
         """Replace selection with items in list"""
+        self.addToHistory()
         self[:] = selectList
 
     def selectEmptyCurrent(self):
-        """Add curentItem to an empty seection list"""
+        """Add currentItem to an empty selection list"""
         if not self:
             self.append(self.currentItem)
 
     def addOrRemove(self, item, select=True):
         """Add or remove item from selection list"""
+        self.addToHistory()
         if select:
-            if item not in self:
-                self.append(item)
+            self.append(item)
         else:
             try:
                 self.remove(item)
             except ValueError:
                 pass
 
+    def openSelection(self):
+        """Open ancestors of all selected items"""
+        for item in self:
+            ancestor = item.parent
+            while ancestor:
+                ancestor.open = True
+                ancestor = ancestor.parent
+
     def changeSearchOpen(self, selectList):
         """Replace selection with items in list,
            if open search enabled, close previously selected search items,
            open new selected search items"""
+        if self == selectList:
+            return
         openSearch = globalref.options.boolData('OpenSearchNodes')
         if openSearch:
             for item in self.searchOpenList:
                 item.open = False
-                globalref.updateViewTreeItem(item)
+                globalref.updateViewItem(item)
         self.searchOpenList = []
         for item in selectList:
             parents = item.openParents(openSearch)
             parents.reverse()  # must start with a visible (loaded) node
             self.searchOpenList.extend(parents)
         for item in self.searchOpenList:
-            globalref.updateViewTreeItem(item)
+            globalref.updateViewItem(item)
+        self.addToHistory()
         self[:] = selectList
         globalref.updateViewSelection()
 
-    def sortList(self):
-        """Replace selection list with a version sorted by tree order"""
-        self[:] = [item for item in \
-                   globalref.docRef.root.descendantList(False) \
-                   if item in self]
+    def addToHistory(self):
+        """Add selection list to previous selection list"""
+        if self:
+            self.prevSelects.append(list(self))
+            if len(self.prevSelects) > TreeSelection.maxHistoryLength:
+                del self.prevSelects[:5]
+            self.nextSelects = []
+
+    def restorePrevSelect(self):
+        """Go back to the most recent saved selection"""
+        self.validateHistory()
+        if self.prevSelects:
+            for item in self.prevSelects[-1]:
+                item.openParents(False)
+                globalref.updateViewItem(item)
+            self.nextSelects.append(list(self))
+            self[:] = self.prevSelects.pop(-1)
+            globalref.updateViewSelection()
+        else:
+            globalref.updateViewMenuStat()
+
+    def restoreNextSelect(self):
+        """Go forward to the most recent saved selection"""
+        self.validateHistory()
+        if self.nextSelects:
+            for item in self.nextSelects[-1]:
+                item.openParents(False)
+                globalref.updateViewItem(item)
+            self.prevSelects.append(list(self))
+            self[:] = self.nextSelects.pop(-1)
+            globalref.updateViewSelection()
+        else:
+            globalref.updateViewMenuStat()
+
+    def validateHistory(self):
+        """Clear previous and next lists if no longer valid"""
+        if self.prevSelects:
+            for item in self.prevSelects[-1]:
+                if not item.isValid():
+                    self.prevSelects = []
+                    break
+        if self.nextSelects:
+            for item in self.nextSelects[-1]:
+                if not item.isValid():
+                    self.nextSelects = []
+                    break
+
+    def formatNames(self):
+        """Return a list of format type names used in the selection"""
+        currentTypes = []
+        for item in self:
+            if item.formatName not in currentTypes:
+                currentTypes.append(item.formatName)
+        return currentTypes
+
+    def uniqueBranches(self):
+        """Return a list of unique branch top items"""
+        result = []
+        for item in self:
+            parent = item.parent
+            while parent and parent not in self:
+                parent = parent.parent
+            if not parent:
+                result.append(item)
+        return result
 
     def treeSelectPrev(self):
         """Select previous item"""
@@ -97,7 +176,7 @@ class TreeSelection(list):
             self.change([self.currentItem])
         for item in self:
             item.open = True
-            globalref.updateViewTreeItem(item)
+            globalref.updateViewItem(item)
 
     def treeCloseItem(self):
         """Set selection to closed"""
@@ -112,7 +191,7 @@ class TreeSelection(list):
                 newSelects.append(item.parent)
         for item in newSelects:
             item.open = False
-            globalref.updateViewTreeItem(item)
+            globalref.updateViewItem(item)
         self.change([item for item in newSelects if item.allAncestorsOpen()])
 
     def treePrevSibling(self):
@@ -143,10 +222,9 @@ class TreeSelection(list):
         item = globalref.docRef.root.lastDescendant(False)
         self.change([item])
 
-    def findText(self, searchStr, forward=True):
+    def findText(self, wordList, forward=True):
         """Select item containing words in searchStr in any field,
-           starts with currentItem, return True if found"""
-        wordList = [text.lower() for text in searchStr.split()]
+           starts with currentItem, return item if found"""
         fullList = globalref.docRef.root.descendantList(True)
         currentPos = fullList.index(self.currentItem)
         fullList = fullList[currentPos+1:] + fullList[:currentPos]
@@ -155,8 +233,8 @@ class TreeSelection(list):
         for item in fullList:
             if item.matchWords(wordList):
                 self.changeSearchOpen([item])
-                return True
-        return False
+                return item
+        return None
 
     def findTitleText(self, searchStr):
         """Select item containing searchStr in the title,
@@ -214,7 +292,7 @@ class TreeSelection(list):
         fullList = globalref.docRef.root.descendantList(False)
         currentPos = fullList.index(self.currentItem)
         fullList = fullList[currentPos+1:] + fullList[:currentPos]
-        matches = [item for item in fullList \
+        matches = [item for item in fullList
                    if item.title()[0].upper() == char]
         if matches:
             if forward:
