@@ -13,11 +13,11 @@
 #*****************************************************************************
 
 import copy
-import types
 import string
 from PyQt4 import QtCore, QtGui
 import treedoc
 import treeitem
+import treemainwin
 import optiondefaults
 import globalref
 
@@ -73,8 +73,7 @@ class TreeView(QtGui.QTreeWidget):
         self.setRootIsDecorated(True)
         self.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
         self.setEditTriggers(QtGui.QAbstractItemView.SelectedClicked)
-        self.setIndentation(globalref.options.intData('IndentOffset', 0,
-                                               optiondefaults.maxIndentOffset))
+        self.updateGenOptions()
         self.setDragEnabled(True)
         self.setAcceptDrops(True)
         self.setDropIndicatorShown(True)
@@ -83,6 +82,7 @@ class TreeView(QtGui.QTreeWidget):
         self.incremSearchStr = ''
         self.blockColumnResize = False
         self.editedItem = None
+        self.noSelectClickCallback = None
         self.connect(self, QtCore.SIGNAL('itemExpanded(QTreeWidgetItem*)'),
                      self.loadItemChildren)
         self.connect(self, QtCore.SIGNAL('itemCollapsed(QTreeWidgetItem*)'),
@@ -159,6 +159,15 @@ class TreeView(QtGui.QTreeWidget):
         if not self.blockColumnResize:
             self.resizeColumnToContents(0)
 
+    def updateGenOptions(self):
+        """Update tree option settings"""
+        self.setIndentation(globalref.options.intData('IndentOffset', 0,
+                            optiondefaults.maxIndentOffset))
+        if globalref.options.boolData('ClickRename'):
+            self.setEditTriggers(QtGui.QAbstractItemView.SelectedClicked)
+        else:
+            self.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
+
     def setCollapsed(self, treeViewItem):
         """Set collapsing item to closed"""
         treeViewItem.docItemRef.open = False
@@ -213,26 +222,29 @@ class TreeView(QtGui.QTreeWidget):
         """Begin iterative search"""
         self.incremSearchMode = True
         self.incremSearchStr = ''
-        globalref.setStatusBar(_('Search for:'))
+        globalref.setStatusBar(_('Search for:'), 0, True)
 
     def doIncremSearch(self):
         """Search for searchStr in all titles"""
-        globalref.setStatusBar(_('Search for: %s') % self.incremSearchStr)
+        globalref.setStatusBar(_('Search for: %s') % self.incremSearchStr,
+                               0, True)
         if globalref.docRef.selection.findTitleText(self.incremSearchStr):
-            globalref.setStatusBar(_('Search for: %s') % self.incremSearchStr)
+            globalref.setStatusBar(_('Search for: %s') % self.incremSearchStr,
+                                   0, True)
         else:
             globalref.setStatusBar(_('Search for: %s  (not found)') %
-                                             self.incremSearchStr)
+                                   self.incremSearchStr, 0, True)
 
     def treeIncremNext(self):
         """Search for next occurance of increm string"""
         if self.incremSearchStr:
             if globalref.docRef.selection.findNextTitle(self.incremSearchStr,
                                                         True):
-                globalref.setStatusBar(_('Next:  %s') % self.incremSearchStr)
+                globalref.setStatusBar(_('Next:  %s') % self.incremSearchStr,
+                                       0, True)
             else:
                 globalref.setStatusBar(_('Next:  %s  (not found)') %
-                                       self.incremSearchStr)
+                                       self.incremSearchStr, 0, True)
 
     def treeIncremPrev(self):
         """Search for previous occurance of increm string"""
@@ -240,10 +252,10 @@ class TreeView(QtGui.QTreeWidget):
             if globalref.docRef.selection.findNextTitle(self.incremSearchStr,
                                                         False):
                 globalref.setStatusBar(_('Previous:  %s') %
-                                       self.incremSearchStr)
+                                       self.incremSearchStr, 0, True)
             else:
                 globalref.setStatusBar(_('Previous:  %s  (not found)') %
-                                       self.incremSearchStr)
+                                       self.incremSearchStr, 0, True)
 
     def showTypeMenu(self):
         """Show popup menu for changing the item type"""
@@ -276,9 +288,15 @@ class TreeView(QtGui.QTreeWidget):
 
     def dropMimeData(self, parent, mimeData, isCopy=False):
         """Decode dropped data"""
+        mainWin = self.parent().parent().parent().parent()
+        oldMainWin = globalref.mainWin
+        if globalref.treeControl.duplicateWindows():
+            oldMainWin.saveMultiWinTree()
+        globalref.updateRefs(mainWin)
         text = unicode(mimeData.data('text/xml'), 'utf-8')
         root, newFormats = globalref.docRef.readXmlStringAndFormat(text)
         if not root:
+            globalref.updateRefs(oldMainWin)
             return False
         if root.formatName == treedoc.TreeDoc.copyFormat.name:
             itemList = root.childList
@@ -292,8 +310,8 @@ class TreeView(QtGui.QTreeWidget):
                 globalref.docRef.treeFormats.addIfMissing(format)
             globalref.docRef.treeFormats.updateDerivedTypes()
             globalref.docRef.treeFormats.updateUniqueID()
-            if globalref.mainWin.configDlg:
-                globalref.mainWin.configDlg.resetParam()
+            if treemainwin.TreeMainWin.configDlg:
+                treemainwin.TreeMainWin.configDlg.resetParam()
         else:
             globalref.docRef.undoStore.addChildListUndo(undoParents)
         for node in itemList:
@@ -305,6 +323,9 @@ class TreeView(QtGui.QTreeWidget):
         if newFormats:
             globalref.docRef.treeFormats.updateAutoChoices()
         globalref.updateViewAll()
+        globalref.updateRefs(oldMainWin)
+        if globalref.treeControl.duplicateWindows():
+            oldMainWin.updateMultiWinTree()
         return True
 
     def mousePressEvent(self, event):
@@ -317,6 +338,10 @@ class TreeView(QtGui.QTreeWidget):
         if not clickedItem:  # skip unselecting click on blank space
             self.dragStartPos = None
             return
+        if self.noSelectClickCallback:
+            self.noSelectClickCallback(clickedItem.docItemRef)
+            self.noSelectClickCallback = None
+            return
         if event.button() == QtCore.Qt.LeftButton:
             self.dragStartPos = QtCore.QPoint(event.pos())
         elif event.button() == QtCore.Qt.RightButton:
